@@ -1,6 +1,8 @@
 from datetime import datetime
 from typing import Any
 from pydantic import BaseModel
+
+from tracardi.domain.value_object.storage_info import StorageInfo
 from tracardi.service.storage.collection_crud import CollectionCrud
 from tracardi.service.storage.crud import StorageCrud
 
@@ -28,6 +30,13 @@ class Console(BaseModel):
     def storage(self) -> StorageCrud:
         return StorageCrud("console-log", Console, entity=self)
 
+    @staticmethod
+    def storage_info() -> StorageInfo:
+        return StorageInfo(
+            'console-log',
+            Console
+        )
+
 
 class ConsoleLog(list):
 
