@@ -7,6 +7,7 @@ from .entity import Entity
 from .metadata import Metadata
 from .settings import Settings
 from .time import Time
+from .value_object.storage_info import StorageInfo
 
 
 class FlowActionPlugin(Entity):
@@ -25,3 +26,10 @@ class FlowActionPlugin(Entity):
 
     def storage(self) -> StorageCrud:
         return StorageCrud("action", FlowActionPlugin, entity=self)
+
+    @staticmethod
+    def storage_info() -> StorageInfo:
+        return StorageInfo(
+            'action',
+            FlowActionPlugin
+        )
