@@ -15,6 +15,7 @@ from ..value_object.save_result import SaveResult
 from ..value_object.tracker_payload_result import TrackerPayloadResult
 from ...config import tracardi
 from ...process_engine.rules_engine import RulesEngine
+from ...service.storage.factory import storage
 
 
 class TrackerPayload(BaseModel):
@@ -63,7 +64,8 @@ class TrackerPayload(BaseModel):
 
         # Save profile
         if save_profile and profile.operation.new:
-            profile_result = await profile.storage().save()
+            profile_result = await storage(profile).save()
+            # profile_result = await profile.storage().save()
         else:
             profile_result = BulkInsertResult()
 
