@@ -1,4 +1,5 @@
 from tracardi.domain.entity import Entity
+from tracardi.domain.value_object.storage_info import StorageInfo
 from tracardi.service.storage.collection_crud import CollectionCrud
 from tracardi.service.storage.crud import StorageCrud
 
@@ -9,6 +10,13 @@ class Project(Entity):
     def storage(self) -> StorageCrud:
         return StorageCrud("project", Project, entity=self)
 
+    @staticmethod
+    def storage_info() -> StorageInfo:
+        return StorageInfo(
+            'project',
+            Project
+        )
+
 
 class Projects(list):
 
