@@ -1,4 +1,6 @@
 from typing import Dict, List
+
+from tracardi.domain.value_object.storage_info import StorageInfo
 from tracardi_graph_runner.domain.debug_info import DebugInfo
 from tracardi.domain.entity import Entity
 from tracardi.service.secrets import b64_encoder, b64_decoder
@@ -30,3 +32,10 @@ class EventDebugRecord(Entity):
 
     def storage(self) -> StorageCrud:
         return StorageCrud("debug-info", EventDebugRecord, entity=self)
+
+    @staticmethod
+    def storage_info() -> StorageInfo:
+        return StorageInfo(
+            'debug-info',
+            EventDebugRecord
+        )
