@@ -1,9 +1,7 @@
+import tracardi
 from typing import List
-
 from pydantic import BaseModel
 
-import tracardi.domain.profile
-
 from tracardi.event_server.service.persistence_service import PersistenceService
 from tracardi.service.storage.elastic_storage import ElasticStorage
 
@@ -24,7 +22,6 @@ class Operation(BaseModel):
         return isinstance(self.merge, list) and len(self.merge) > 0
 
     @staticmethod
-    async def load_profiles_to_merge(merge_key_values: List[tuple], limit=1000) -> List[
-        'tracardi.domain.profile.Profile']:
+    async def load_profiles_to_merge(merge_key_values: List[tuple], limit=1000) -> List['tracardi.domain.profile.Profile']:
         profiles = await PersistenceService(ElasticStorage('profile')).load_by_values(merge_key_values, limit)
         return [tracardi.domain.profile.Profile(**profile) for profile in profiles]
