@@ -23,6 +23,8 @@ from ..domain.rules import Rules
 from ..service.storage.collection_crud import CollectionCrud
 import asyncio
 
+from ..service.storage.factory import storage
+
 
 class RulesEngine:
 
@@ -202,7 +204,8 @@ class RulesEngine:
 
             # Must be the last operation
             if self.profile.operation.needs_update():
-                save_tasks.append(asyncio.create_task(self.profile.storage().save()))
+                # save_tasks.append(asyncio.create_task(self.profile.storage().save()))
+                save_tasks.append(asyncio.create_task(storage(self.profile).save()))
 
             # run save tasks
             await asyncio.gather(*save_tasks)
